#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_NBTRUE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_NBTRUE_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/simd/nbtrue.hpp>

#endif
